pub struct Facet {
pub name: String,
pub values: Vec<FacetValue>,
}Expand description
A facet is a filterable dimension with all its possible values.
Fields
name: StringName of the facet (e.g., “status”, “category”).
values: Vec<FacetValue>All possible values for this facet, sorted by count descending.
Implementations